@@ -19,6 +19,8 @@ static void _blur( SDL_Surface *source, SDL_Surface *target, int radius, char ve
     int x,y,ra,n,s,o1,o2;
     double r2;
     int pxcnt = 0;
+
+    /* Get sdl_surface attributes */
     int w = source->w;
     int h = source->h;
     SDL_PixelFormat *source_format = (SDL_PixelFormat *)source->format;
@@ -26,6 +28,7 @@ static void _blur( SDL_Surface *source, SDL_Surface *target, int radius, char ve
     Uint32 *source_pixels = (Uint32 *) source->pixels;
     Uint32 *target_pixels = (Uint32 *) target->pixels;
 
+    /* Vertical/horizonal depending values */
     s = (vertical)?h:w;
     o1 = (vertical)?1:0;
     o2 = (vertical)?0:1;
@@ -39,6 +42,7 @@ static void _blur( SDL_Surface *source, SDL_Surface *target, int radius, char ve
             ra = -radius;
             n = (vertical)?y:x;
 
+            /* Sum of pixel within radius */
             while( ra <= radius ){
                 if( (n+ra) >= 0 && (n+ra) < s ){
                     pix = source_pixels[pxcnt + (int)( ((ra * o1) * w) + (ra * o2))];
@@ -51,10 +55,14 @@ static void _blur( SDL_Surface *source, SDL_Surface *target, int radius, char ve
             pxcnt++;
             if(sa == 0) continue;
             if(color_cnt <= 1) continue;
-            sr = sr/color_cnt;
-            sg = sg/color_cnt;
-            sb = sb/color_cnt;
-            sa = sa/color_cnt;
+
+            /* average channel value */
+            sr = sr / color_cnt;
+            sg = sg / color_cnt;
+            sb = sb / color_cnt;
+            sa = sa / color_cnt;
+
+            /* map & set pixel */
             pix = SDL_MapRGBA( target_format, (Uint8)sr, (Uint8)sg, 
                 (Uint8)sb, (Uint8)sa);
             target_pixels[pxcnt-1] = pix;
@@ -82,7 +90,7 @@ static PyObject* noise( PyObject* self, PyObject* args )
     int rnd,tr,tg,tb;
 
     PY_PARSEARGS_BEGIN
-        "O|ii", &py_surface,&value,&density
+        "O|ii", &py_surface, &value, &density
     PY_PARSEARGS_END
 
     getSurfaceAttrs(py_surface, &w, &h, &format, &pixels);
@@ -93,11 +101,11 @@ static PyObject* noise( PyObject* self, PyObject* args )
             if( rand()%density != 0 ) continue;
             pixel = pixels[(y*w)+x];
             SDL_GetRGBA( pixel, format, &r, &g, &b, &a );
-            rnd = (value/2) - (rand()%value);
-            tr = r+rnd;
-            tg = g+rnd;
-            tb = b+rnd;
-            
+
+            rnd = (value / 2) - (rand() % value);
+            tr = r + rnd;
+            tg = g + rnd;
+            tb = b + rnd;
             r = clampUint8(tr);
             g = clampUint8(tg);
             b = clampUint8(tb);
@@ -208,6 +216,39 @@ static PyObject* scratch( PyObject* self, PyObject* args )
     return Py_None;
 }
 
+/*
+    Simple image scratching.
+*/
+static PyObject* pixelize( PyObject* self, PyObject* args )
+{
+    PyObject* py_surface = NULL;
+    PySurfaceObject* c_surface;
+    Uint32 *pixels;
+    int w,h,x,y,rx,ry = 0;
+    Uint32 pixel;
+    SDL_PixelFormat *format = NULL;
+
+    int offset = 10;
+
+    PY_PARSEARGS_BEGIN
+        "O|ib", &py_surface, &offset
+    PY_PARSEARGS_END
+
+    getSurfaceAttrs(py_surface, &w, &h, &format, &pixels);
+
+    for( y = 0; y < h; y ++ ){
+        for( x = 0; x < w; x ++ ){
+            rx = (x / offset) * offset;
+            ry = (y / offset) * offset;
+            pixel = pixels[(ry*w)+rx];
+            pixels[ (y*w)+x ] = pixel;
+        }
+    }
+    
+    Py_INCREF(Py_None);
+    return Py_None;
+}
+
 
 /*
     Horizontal/vertical gradient.
@@ -317,11 +358,12 @@ static PyObject* shadow(PyObject* self, PyObject* args)
     
     if( resized ){
         /* Set offsets for resized surface */
-        rw = w + (radius*2);
-        rh = h + (radius*2);
+        rw = w + (radius * 2);
+        rh = h + (radius * 2);
         offset = radius;
     } else {
-        rw = w;rh = h;
+        rw = w;
+        rh = h;
         offset = 0;
     }
 
@@ -436,6 +478,7 @@ static PyMethodDef FiltersMethods[] = {
     {"noiseBlur", noiseBlur, METH_VARARGS, "Simple surface noise"},
     {"shadow", shadow, METH_VARARGS, "Create RGBA surface shadow"},
     {"scratch", scratch, METH_VARARGS, "Create RGBA surface shadow"},
+    {"pixelize", pixelize, METH_VARARGS, "Fast pixelize effect"},
     {NULL, NULL, NULL, NULL}
 };
 
