@@ -155,6 +155,8 @@ tester.addTests([
                  pgext.filters.noiseBlur, [20, 1]),
                 ("filters.scratch", "modify-inplace",
                  pgext.filters.scratch, [5]),
+                ("filters.pixelize", "modify-inplace",
+                 pgext.filters.pixelize, [10]),
 
                 ("filters.gradient1", "make", pgext.filters.gradient,
                  [(200, 200), (100, 100, 200), (100, 200, 100), 0, 1.0]),
